# YouQu3 架构设计

## 1. 背景

YouQu 在公司内部已经被大量 AT 项目使用，在公司的多个自动化流程中运行得很好，完全能满足公司对自动化测试的业务需求，也得到了公司领导、同事们、内外部开发者们的认可，但 YouQu 在现有框架下，仍然存在一些问题，比如：每次使用需要初始化框架工程及单独做环境部署，操作较为复杂、源代码暴露在用户面前，导致框架代码容易被用户拉过去魔改、绑定了太多公司的业务等等。

有些问题处理起来必然会影响到框架的兼容性，势必对现有公司业务流程有一些影响，因此我们才萌生了对框架结构进行重新设计想法，我们想要设计开发一个更加简单易用、更加纯粹、扩展性和兼容性更好的自动化测试框架。

## 2. 目标

- 支持离线部署
- 极致轻量化依赖
- 功能可插拔
- 可视化配置
- 支持非开发者下运行

## 3. 架构设计

### 3.1 总体方案

### 3.2 架构总览

### 3.3 核心流程

### 3.4 详细设计

## 4. 演进规划
